@@ -290,14 +290,13 @@ int AL_Externalize(IN AL_AccessList *Alist, OUT AL_ExternalAccessList *Elist){
    successful conversion. Returns -1 if ANY name in the access list is not
    translatable, or if the total number of entries is greater than
    AL_MaxExtEntries. */
-int AL_Internalize(IN AL_ExternalAccessList Elist, OUT AL_AccessList **Alist){
-	register int i;
-	register char *nextc;
-	int m, p;
-	char tbuf[PRS_MAXNAMELEN+1];
+int AL_Internalize(IN AL_ExternalAccessList Elist, OUT AL_AccessList **Alist)
+{
+	int i, m, p;
+	char *nextc, tbuf[PRS_MAXNAMELEN+1];
 
-	if (sscanf(Elist, "%d\n%d\n", &p, &m) != 2) return (-1);
-	if (p + m > AL_MaxExtEntries) return(-1);
+	if (sscanf(Elist, "%d\n%d\n", &p, &m) != 2) return EINVAL;
+	if (p + m > AL_MaxExtEntries) return E2BIG;
 	AL_NewAlist(p + m, Alist);
 	(*Alist)->PlusEntriesInUse = p;
 	(*Alist)->MinusEntriesInUse = m;
@@ -312,11 +311,12 @@ int AL_Internalize(IN AL_ExternalAccessList Elist, OUT AL_AccessList **Alist){
 		if (sscanf(nextc, "%s\t%d\n", tbuf,
 			   &((*Alist)->ActualEntries[i].Rights)) != 2){
 			AL_FreeAlist(Alist);
-			return(-1);
+			return EINVAL;
 		}
 		if (AL_NameToId(tbuf, &((*Alist)->ActualEntries[i].Id)) < 0){
 			AL_FreeAlist(Alist);
-			return(-1);
+			return ENOENT; /* Unusual error, but we can't return
+					  EINVAL for everything */
 		}
 		nextc = (char *)(1 + strchr(nextc, '\n'));
 	}
@@ -325,7 +325,7 @@ int AL_Internalize(IN AL_ExternalAccessList Elist, OUT AL_AccessList **Alist){
 	       (int (*)(const void *, const void *))CmpPlus); 
 	qsort( (char *)&((*Alist)->ActualEntries[m]),m, sizeof(AL_AccessEntry),
  	       (int (*)(const void *, const void *))CmpMinus); 
-	return(0);
+	return 0;
 }
 
 
@@ -523,13 +523,15 @@ int AL_GetExternalCPS(IN int Id, OUT PRS_ExternalCPS *ECPS){
 
 
 /* Returns 0 iff Id is in the CPS. Else returns -1. */
-int AL_IsAMember(int Id, PRS_InternalCPS *CPS){
+int AL_IsAMember(int Id, PRS_InternalCPS *CPS)
+{
 	int i;
     
 	/* Yes, I know we can do a binary search on IdList */
 	for (i=0;i < CPS->InclEntries;i++)
-		if (CPS->IdList[i] == Id) return(0);
-	return(-1);
+		if (CPS->IdList[i] == Id)
+		    return(1);
+	return(0);
 }
 
 
