@@ -308,7 +308,7 @@ int executor(char *pathname, int vuid, int req_no)
 		    quit("File %s is not a regular file (and hence cannot be used for repair)", fixed);
 
 		if (!repair_getfid(fixed, &fixfid, fixrealm, &fixvv, space, sizeof(space)) && (fixvv.StoreId.Host != (unsigned long)-1))
-		    sprintf(fixfile, "@%lx.%lx.%lx@%s", fixfid.Volume, fixfid.Vnode, fixfid.Unique, fixrealm);
+		    sprintf(fixfile, "@%08x.%08x.%08x@%s", fixfid.Volume, fixfid.Vnode, fixfid.Unique, fixrealm);
 		else strcpy(fixfile, fixed);
 
 		if (EndRepair(repv, 1, space, sizeof(space)) < 0)
@@ -644,7 +644,7 @@ long S_ServerConnectionWeak(RPC2_Handle _cid, RPC2_String ServerName) {
     return(RPC2_SUCCESS);
 }
 
-long S_NetworkQualityEstimate(RPC2_Handle _cid, long numEstimates, QualityEstimate serverList[]) {
+long S_NetworkQualityEstimate(RPC2_Handle _cid, RPC2_Integer numEstimates, QualityEstimate serverList[]) {
 
     return(RPC2_SUCCESS);
 }
@@ -784,9 +784,11 @@ long S_InvokeASR(RPC2_Handle _cid, RPC2_String pathname, RPC2_Integer realmid,
     int ret;
     struct pnode *pinfo, *ptmp;
     RPC2_SubsysIdent subsysid;
+    char *rock;
 
-    if ((ret = LWP_GetRock(DEF_ROCK, (char **)&pinfo)) != LWP_SUCCESS)
+    if ((ret = LWP_GetRock(DEF_ROCK, &rock)) != LWP_SUCCESS)
 	quit("Could not get LWP node from under rock (%d)", ret);
+    pinfo = (struct pnode *)rock;
 
   /* fork off the executor */
     ret = fork();
