@@ -692,7 +692,7 @@ class fsobj {
     void RemoveShadow();
     void CacheReport(int, int);
 
-    int /*(secs)*/ fsobj::EstimatedFetchCost(int =1);  /* 0 = status; 1 = data (default) */
+    int /*(secs)*/ EstimatedFetchCost(int =1);  /* 0 = status; 1 = data (default) */
     void RecordReplacement(int, int);
 
     void print() { print(stdout); }
@@ -763,7 +763,8 @@ extern void PrintCacheStats(char* description, CacheStats *, int);
 extern void VenusToViceStatus(VenusStat *, ViceStatus *);
 
 /* fso_daemon.c */
-extern void FSOD_Init(void);
+void FSOD_Init(void);
+void FSOD_ReclaimFSOs(void);
 
 /* More locking macros. */
 #define	FSO_HOLD(f)	    { (f)->refcnt++; }
