@@ -32,7 +32,6 @@ extern "C" {
 }
 #endif
 
-#include <rvmlib.h>
 #include "realm.h"
 #include "realmdb.h"
 #include "comm.h"
@@ -78,9 +77,7 @@ Realm::~Realm(void)
     rec_list_del(&realms);
     if (rootservers) {
 	eprint("Removing realm '%s'", name);
-
-	RPC2_freeaddrinfo(rootservers);
-	rootservers = NULL;
+	ReplaceRootServers();
     }
     rvmlib_rec_free(name); 
     rvmlib_rec_free(rootvolname); 
@@ -145,49 +142,84 @@ void Realm::PutRef(void)
 #endif
 }
 
+void Realm::ReplaceRootServers(struct RPC2_addrinfo *newsrvs)
+{
+    struct RPC2_addrinfo *p, *oldsrvs;
+    struct sockaddr_in *sin;
+    srvent *s;
+
+    /* grab an extra reference count to pin down the new servers */
+    for (p = newsrvs; p; p = p->ai_next) {
+	if (p->ai_family != PF_INET)
+	    continue;
+
+	sin = (struct sockaddr_in *)p->ai_addr;
+	s = ::GetServer(&sin->sin_addr, Id());
+	s->GetRef();
+	PutServer(&s);
+    }
+
+    oldsrvs = rootservers;
+    rootservers = newsrvs;
+
+    /* drop the reference count on the old root servers */
+    for (p = oldsrvs; p; p = p->ai_next) {
+	if (p->ai_family != PF_INET)
+	    continue;
+
+	sin = (struct sockaddr_in *)p->ai_addr;
+	s = ::GetServer(&sin->sin_addr, Id());
+	s->PutRef();
+	PutServer(&s);
+    }
+    RPC2_freeaddrinfo(oldsrvs);
+}
+
 /* Get a connection to any server (as root). */
 /* MUST NOT be called from within a transaction */
 int Realm::GetAdmConn(connent **cpp)
 {
-    struct RPC2_addrinfo *p;
-    int code = 0;
-    int tryagain = 0;
-    int unknown = !rootservers;
+    struct RPC2_addrinfo *p, *tmp = NULL;
+    struct sockaddr_in *sin;
+    srvent *s;
+    int code = 0, unknown, resolve;
 
-    LOG(100, ("GetAdmConn: \n"));
+    LOG(100, ("GetAdmConn: %s\n", name));
 
     if (STREQ(name, LOCALREALM))
 	return ETIMEDOUT;
 
     *cpp = 0;
 
+    unknown = resolve = !rootservers;
 retry:
-    if (!rootservers)
-	GetRealmServers(name, "codasrv", &rootservers);
-    else {
+    if (resolve) {
+	struct RPC2_addrinfo *newsrvs = NULL;
+	GetRealmServers(name, "codasrv", &newsrvs);
+	ReplaceRootServers(newsrvs);
+	resolve = 0;
+    } else {
 	coda_reorder_addrinfo(&rootservers);
-	/* our cached addresses might be stale, re-resolve if we can't reach
-	 * any of the servers */
-	tryagain = 1;
+	/* our cached addresses might be stale, re-resolve if we end up not
+	 * reaching any of the servers */
+	resolve = 1;
     }
-
-    if (!rootservers)
-	return ETIMEDOUT;
+    tmp = RPC2_copyaddrinfo(rootservers);
 
     /* Get a connection to any custodian. */
-    for (p = rootservers; p; p = p->ai_next) {
-	struct sockaddr_in *sin;
-	srvent *s;
+    for (p = tmp; p; p = p->ai_next) {
+	if (p->ai_family != PF_INET)
+	    continue;
 
-	CODA_ASSERT(p->ai_family == PF_INET);
 	sin = (struct sockaddr_in *)p->ai_addr;
 
 	s = ::GetServer(&sin->sin_addr, Id());
 	code = s->GetConn(cpp, ANYUSER_UID);
 	PutServer(&s);
+
 	switch(code) {
 	case ERETRY:
-	    tryagain = 1;
+	    resolve = 1;
 	case ETIMEDOUT:
 	    continue;
 
@@ -212,21 +244,23 @@ retry:
 		    Recov_EndTrans(MAXFP);
 		}
 	    }
-	    return code;
+	    goto exit_done;
 
 	default:
 	    if (code < 0)
 		eprint("GetAdmConn: bogus code (%d)", code);
-	    return code;
+	    goto exit_done;
 	}
     }
-    if (tryagain) {
-	RPC2_freeaddrinfo(rootservers);
-	rootservers = NULL;
-	tryagain = 0;
+    if (resolve)
 	goto retry;
-    }
-    return ETIMEDOUT;
+
+    code = ETIMEDOUT;
+
+exit_done:
+    if (tmp)
+	RPC2_freeaddrinfo(tmp);
+    return code;
 }
 
 
