@@ -54,7 +54,6 @@ extern "C" {
 #include "user.h"
 #include "venus.private.h"
 #include "venuscb.h"
-#include "venuswb.h"
 #include "venusrecov.h"
 #include "venusvol.h"
 #include "vproc.h"
@@ -127,7 +126,7 @@ struct in_addr venus_relay_addr = { INADDR_LOOPBACK };
 /* *****  venus.c  ***** */
 
 /* socket connecting us back to our parent */
-int parent = -1;
+int parent_fd = -1;
 
 /* local-repair modification */
 int main(int argc, char **argv)
@@ -138,8 +137,12 @@ int main(int argc, char **argv)
     ParseCmdline(argc, argv);
     DefaultCmdlineParms();   /* read /etc/coda/venus.conf */
 
+    // Cygwin runs as a service and doesn't need to daemonize.
+#ifndef __CYGWIN__
     if (LogLevel == 0)
-	parent = daemonize();
+	parent_fd = daemonize();
+#endif
+
     update_pidfile(VenusPidFile);
 
     /* open the console file and print vital info */
@@ -198,7 +201,6 @@ int main(int argc, char **argv)
     MarinerInit();  /* set up mariner socket */
     WorkerInit();   /* open kernel device */
     CallBackInit(); /* set up callback subsystem and create callback server threads */
-    WritebackInit(); /* set up writeback subsystem */
     AdviceInit();   /* set up AdSrv and start the advice daemon */
     LRInit();	    /* set up local-repair database */
 
@@ -255,7 +257,7 @@ int main(int argc, char **argv)
     fflush(logFile);
     fflush(stderr);
 
-    MarinerLog("shutdown in progress");
+    MarinerLog("shutdown in progress\n");
 
     LWP_TerminateProcessSupport();
 
