@@ -80,13 +80,6 @@ class resent;
 /* Was: EXCLUSIVE, *SHARED*: name clash on Solaris */
 enum VolLockType { EX_VOL_LK, SH_VOL_LK };
 
-/* XXX These should be in vice.h! */
-/* On the wire, all these operations map to OLDCML_NewStore_PTR */
-#define	OLDCML_Truncate_OP	100
-#define	OLDCML_Utimes_OP	101
-#define	OLDCML_Chown_OP	        102
-#define	OLDCML_Chmod_OP	        103
-
 
 /*  *****  Constants  *****  */
 
@@ -201,11 +194,10 @@ class ClientModifyLog {
 
     void AttachFidBindings();
 
-    long logBytes() {return bytes;}
-    long logBytesHighWater() {return bytesHighWater;}
-    long size();
+    long logBytes() { return bytes; }
+    long logBytesHighWater() { return bytesHighWater; }
     int count() { return list.count(); }
-    long countHighWater() {return entriesHighWater;}
+    long countHighWater() { return entriesHighWater; }
     uid_t Owner() { return owner; }
 
     void print() { print(stdout); }
@@ -447,6 +439,7 @@ class cml_iterator {
 void VolDaemon(void) /* used to be member of class vdb (Satya 3/31/95) */;
 void TrickleReintegrate(); /* used to be in class vdb (Satya 5/20/95) */
 
+class fsobj;
 
 /* Volume Database.  Dictionary for volume entries (volents). */
 class vdb {
@@ -489,7 +482,6 @@ class vdb {
     /* Daemon functions. */
     void GetDown();
     void FlushCOP2();
-    void WriteBack();
     void CheckPoint(unsigned long);
     void CheckReintegratePending();
     void CheckLocalSubtree();
@@ -644,7 +636,8 @@ class volent {
 
     /* User-visible volume status. */
     int GetVolStat(VolumeStatus *, RPC2_BoundedBS *,
-		   VolumeStateType *, int *, int *,
+		   VolumeStateType *, unsigned int *age, unsigned int *hogtime,
+		   int *conflict, int *cml_size, uint64_t *cml_bytes,
 		    RPC2_BoundedBS *, RPC2_BoundedBS *, uid_t, int local_only);
     int SetVolStat(VolumeStatus *, RPC2_BoundedBS *,
 		    RPC2_BoundedBS *, RPC2_BoundedBS *, uid_t);
