@@ -208,7 +208,8 @@ static int AllocReintegrateVnode(Volume **, dlist *, ViceFid *, ViceFid *,
 
 static int AddParent(Volume **, dlist *, ViceFid *);
 static int ReintNormalVCmp(int, VnodeType, void *, void *);
-static void ReintPrelimCOP(vle *, const ViceStoreId *, ViceStoreId *, Volume *);
+static void ReintPrelimCOP(vle *, const ViceStoreId *oldSID,
+			   const ViceStoreId *newSID);
 static void ReintFinalCOP(vle *, Volume *, RPC2_Integer *);
 static int ValidateRHandle(VolumeId, ViceReintHandle *);
 
@@ -244,21 +245,21 @@ long FS_ViceReintegrate(RPC2_Handle RPCid, VolumeId Vid, RPC2_Integer LogSize,
 		goto FreeLocks;
 	}
 
-	SLog(1, "Starting ValidateReintegrateParms for %#x", Vid);
+	SLog(1, "Starting ValidateReintegrateParms for %x", Vid);
 
 	/* Phase I. */
 	if ((errorCode = ValidateReintegrateParms(RPCid, &Vid, &volptr, &client,
 						 LogSize, &rlog, Index, 0)))
 		goto FreeLocks;
 	
-	SLog(1, "Starting  GetReintegrateObjects for %#x", Vid);
+	SLog(1, "Starting GetReintegrateObjects for %x", Vid);
 
 	/* Phase II. */
 	if ((errorCode = GetReintegrateObjects(client, &rlog, vlist, 
 					      &blocks, Index)))
 		goto FreeLocks;
 
-	SLog(1, "Starting  CheckSemanticsAndPerform for %#x", Vid);
+	SLog(1, "Starting CheckSemanticsAndPerform for %x", Vid);
 
 	/* Phase III. */
 	if ((errorCode = CheckSemanticsAndPerform(client, Vid, VSGVolnum, &rlog,
@@ -268,7 +269,7 @@ long FS_ViceReintegrate(RPC2_Handle RPCid, VolumeId Vid, RPC2_Integer LogSize,
  FreeLocks:
 	/* Phase IV. */
 
-	SLog(1, "Starting PutReintegrateObjects for %#x", Vid);
+	SLog(1, "Starting PutReintegrateObjects for %x", Vid);
 
 	PutReintegrateObjects(errorCode, volptr, &rlog, vlist, blocks,
 			      OutOfOrder, client, MaxDirs, NumDirs, StaleDirs,
@@ -334,16 +335,18 @@ long FS_ViceQueryReintHandle(RPC2_Handle RPCid, VolumeId Vid,
     ClientEntry *client = 0;
     int fd = -1;
     struct stat status;
+    char *rock;
 
-    SLog(0/*1*/, "ViceQueryReintHandle for volume 0x%x", Vid);
+    SLog(0/*1*/, "ViceQueryReintHandle for volume %x", Vid);
 
     *Length = (RPC2_Unsigned)-1;
 
     /* Map RPC handle to client structure. */
-    if ((errorCode = (int) RPC2_GetPrivatePointer(RPCid, (char **)&client)) != RPC2_SUCCESS) {
+    if ((errorCode = (int) RPC2_GetPrivatePointer(RPCid, &rock)) != RPC2_SUCCESS) {
 	SLog(0, "ViceQueryReintHandle: GetPrivatePointer failed (%d)", errorCode);
 	goto Exit;
-    }	
+    }
+    client = (ClientEntry *)rock;
 
     if ( (errorCode = ValidateRHandle(Vid, RHandle)) )
 	goto Exit;
@@ -393,14 +396,16 @@ long FS_ViceSendReintFragment(RPC2_Handle RPCid, VolumeId Vid,
     int fd = -1;
     struct stat status;
     SE_Descriptor sid;
+    char *rock;
 
-    SLog(0/*1*/, "ViceSendReintFragment for volume 0x%x", Vid);
+    SLog(0/*1*/, "ViceSendReintFragment for volume %x", Vid);
 
     /* Map RPC handle to client structure. */
-    if ((errorCode = (int) RPC2_GetPrivatePointer(RPCid, (char **)&client)) != RPC2_SUCCESS) {
+    if ((errorCode = (int) RPC2_GetPrivatePointer(RPCid, &rock)) != RPC2_SUCCESS) {
 	SLog(0, "ViceSendReintFragment: GetPrivatePointer failed (%d)", errorCode);
 	goto Exit;
     }	
+    client = (ClientEntry *)rock;
 
     if ( (errorCode = ValidateRHandle(Vid, RHandle)) )
 	goto Exit;
@@ -623,8 +628,7 @@ static int ValidateReintegrateParms(RPC2_Handle RPCid, VolumeId *Vid,
 	    goto Exit;
 	}
 
-	SLog(1,  "Reintegrate transferred %d bytes.",
-		sid.Value.SmartFTPD.BytesTransferred);
+	SLog(1, "Reintegrate transferred %d bytes.", sid.Value.SmartFTPD.BytesTransferred);
     }
 
     OldName = new char[MAXNAMELEN+1];
@@ -907,6 +911,19 @@ static int ValidateReintegrateParms(RPC2_Handle RPCid, VolumeId *Vid,
 		}
 		break;
 
+	    case CML_BrokenRemove_OP:
+		RLE_Unpack(&_ptr, _end, CML_BrokenRemove_PTR, &r->Fid[0],
+			   &r->VV[0], OldName, &r->VV[1], &r->sid);
+
+		memset(&r->VV[0], 0, sizeof(ViceVersionVector));
+		r->Name[0] = strdup(OldName);
+		if (!r->Name[0]) {
+		    errorCode = ENOMEM;
+		    goto Exit;
+		}
+                r->opcode = CML_Remove_OP;
+		break;
+
 	    case CML_Remove_OP:
 		RLE_Unpack(&_ptr, _end, CML_Remove_PTR, &r->Fid[0],
 			   &r->VV[0], OldName, &r->VV[1], &r->sid);
@@ -1026,7 +1043,7 @@ static int ValidateReintegrateParms(RPC2_Handle RPCid, VolumeId *Vid,
 
 	while (i < (*volptr)->nReintegrators) {
 	    if ((r->sid.Host == (*volptr)->reintegrators[i].Host) &&
-		(r->sid.Uniquifier <= (*volptr)->reintegrators[i].Uniquifier)) {
+		((long)r->sid.Uniquifier - (long)(*volptr)->reintegrators[i].Uniquifier <= 0)) {
 		SLog(0, "ValidateReintegrateParms: Already seen id %u < %u)",
 		     r->sid.Uniquifier, (*volptr)->reintegrators[i].Uniquifier);
 		errorCode = VLOGSTALE;
@@ -1313,7 +1330,7 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 
     /* Check each operation and perform it. */
     /* Note: the data transfer part of stores is delayed until all other operations have completed. */
-	SLog(1, "Starting  CheckSemanticsAndPerform for %#x", Vid);
+	SLog(1, "Starting CheckSemanticsAndPerform for %x", Vid);
 
     {
 	struct dllist_head *p;
@@ -1370,7 +1387,7 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 		    HandleWeakEquality(volptr, v->vptr, &r->VV[0]);
 		    PerformStore(client, VSGVolnum, volptr, v->vptr, v->f_finode,
 				 0, r->u.u_store.Length, r->Mtime, &r->sid);
-		    ReintPrelimCOP(v, &r->VV[0].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(v, &r->VV[0].StoreId, &r->sid);
 
 		    /* Cancel previous StoreData. */
 		    v->f_sid = r->sid;
@@ -1458,10 +1475,10 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 				   r->u.u_utimes.Date, r->u.u_chown.Owner,
 				   r->u.u_chmod.Mode, Mask, &r->sid,
 				   &c_inode);
-		    ReintPrelimCOP(v, &r->VV[0].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(v, &r->VV[0].StoreId, &r->sid);
 
 		    {
-			int opcode = (v->d_needsres)
+			int opcode = (v->vptr->disk.type == vDirectory && v->d_needsres)
 			    ? ResolveViceNewStore_OP : RES_NewStore_OP;
 			SLog(5, "Spooling Reintegration newstore record \n");
 			if ((errorCode = 
@@ -1544,17 +1561,20 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 						  &deltablocks);
 			CODA_ASSERT(errorCode == 0);
 
-			ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-			ReintPrelimCOP(child_v, &NullSid, &r->sid, volptr);
+			ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+			ReintPrelimCOP(child_v, &NullSid, &r->sid);
 
 			{
 			    int opcode = (parent_v->d_needsres)
 				? ResolveViceCreate_OP : RES_Create_OP;
-			    if ((errorCode = SpoolVMLogRecord(vlist, parent_v, volptr, 
-							     &r->sid, opcode, 
-							     r->Name[0], 
-							     r->Fid[1].Vnode,
-							     r->Fid[1].Unique))) {
+			    UserId owner = child_v->vptr->disk.owner;
+			    errorCode = SpoolVMLogRecord(vlist, parent_v,
+							 volptr, &r->sid,
+							 opcode, r->Name[0], 
+							 r->Fid[1].Vnode,
+							 r->Fid[1].Unique,
+							 owner);
+			    if (errorCode) {
 				SLog(0, "Reint(CSAP): Error %d during spooling log record for create\n",
 				       errorCode);
 				goto Exit;
@@ -1598,8 +1618,8 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 		    PerformRemove(client, VSGVolnum, volptr, parent_v->vptr,
 				  child_v->vptr, r->Name[0], r->Mtime,
 				  0, &r->sid, &parent_v->d_cinode, &tblocks);
-		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid);
 
 		    {
 			int opcode = (parent_v->d_needsres)
@@ -1653,8 +1673,7 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 			goto Exit;
 
 		    /* directory concurrency check */
-		    if (VV_Cmp(&Vnode_vv(parent_v->vptr), 
-			       &r->VV[0]) != VV_EQ)
+		    if (VV_Cmp(&Vnode_vv(parent_v->vptr), &r->VV[0]) != VV_EQ)
 			parent_v->d_reintstale = 1;
 
 		    /* Perform. */
@@ -1665,8 +1684,8 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 					    r->Name[0], r->Mtime, 0, &r->sid,
 					    &parent_v->d_cinode, &deltablocks);
 		    CODA_ASSERT(errorCode == 0);
-		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid);
 
 		    {
 			int opcode = (parent_v->d_needsres)
@@ -1753,12 +1772,12 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 				  r->Name[0], r->Name[1],
 				  r->Mtime, 0, &r->sid, &sd_v->d_cinode, &td_v->d_cinode,
 				  (s_v->vptr->disk.type == vDirectory ? &s_v->d_cinode : 0), NULL);
-		    ReintPrelimCOP(sd_v, &r->VV[0].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(sd_v, &r->VV[0].StoreId, &r->sid);
 		    if (!SameParent)
-			ReintPrelimCOP(td_v, &r->VV[1].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(s_v, &r->VV[2].StoreId, &r->sid, volptr);
+			ReintPrelimCOP(td_v, &r->VV[1].StoreId, &r->sid);
+		    ReintPrelimCOP(s_v, &r->VV[2].StoreId, &r->sid);
 		    if (TargetExists)
-			ReintPrelimCOP(t_v, &NullSid, &r->sid, volptr); /* XXX wrong? */
+			ReintPrelimCOP(t_v, &NullSid, &r->sid); /* XXX wrong? */
 		    {
 			if (!SameParent) {
 			    /* SpoolRenameLogRecord() only allows one opcode, so we must */
@@ -1828,35 +1847,32 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 					     &parent_v->d_cinode,
 					     &deltablocks);
 		    CODA_ASSERT(errorCode == 0);
-		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(child_v, &NullSid, &r->sid, volptr);
+		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+		    ReintPrelimCOP(child_v, &NullSid, &r->sid);
 
 		    {
 			int p_opcode = (parent_v->d_needsres)
 			  ? ResolveViceMakeDir_OP : RES_MakeDir_OP;
 			int c_opcode = RES_MakeDir_OP;
-			if (!errorCode) {
-			    if ((errorCode = SpoolVMLogRecord(vlist, parent_v, volptr, 
-							     &r->sid, p_opcode, 
-							     r->Name[0],
-							     r->Fid[1].Vnode,
-							     r->Fid[1].Unique,
-							     r->u.u_mkdir.Owner))) {
-				SLog(0, "Reint: Error %d during SpoolVMLogRecord for parent in MakeDir_OP\n",
-				       errorCode);
+			UserId owner = child_v->vptr->disk.owner;
+			errorCode = SpoolVMLogRecord(vlist, parent_v, volptr,
+						     &r->sid, p_opcode,
+						     r->Name[0],
+						     r->Fid[1].Vnode,
+						     r->Fid[1].Unique,
+						     owner);
+			if (errorCode) {
+				SLog(0, "Reint: Error %d during SpoolVMLogRecord for parent in MakeDir_OP\n", errorCode);
 				goto Exit;
-			    }
-			    if ((errorCode = SpoolVMLogRecord(vlist, child_v, 
-							     volptr, &r->sid, 
-							     c_opcode, ".", 
-							     r->Fid[1].Vnode,
-							     r->Fid[1].Unique,
-							     r->u.u_mkdir.Owner))) {
-				SLog(0, 
-				       "Reint:  error %d during SpoolVMLogRecord for child in MakeDir_OP\n",
-				       errorCode);
+			}
+			errorCode = SpoolVMLogRecord(vlist, child_v, volptr,
+						     &r->sid, c_opcode, ".", 
+						     r->Fid[1].Vnode,
+						     r->Fid[1].Unique,
+						     owner);
+			if (errorCode) {
+				SLog(0, "Reint:  error %d during SpoolVMLogRecord for child in MakeDir_OP\n", errorCode);
 				goto Exit;
-			    }
 			}
 		    }
 		    *blocks += deltablocks;
@@ -1896,8 +1912,8 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 		    PerformRmdir(client, VSGVolnum, volptr, parent_v->vptr,
 				 child_v->vptr, r->Name[0], r->Mtime,
 				 0, &r->sid, &parent_v->d_cinode, &tblocks);
-		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid, volptr);
+		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+		    ReintPrelimCOP(child_v, &r->VV[1].StoreId, &r->sid);
 
 		    {
 			int opcode = (parent_v->d_needsres)
@@ -1968,20 +1984,21 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 					       &parent_v->d_cinode,
 					       &deltablocks);
 		    CODA_ASSERT(errorCode == 0);
-		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid, volptr);
-		    ReintPrelimCOP(child_v, &NullSid, &r->sid, volptr);
+		    ReintPrelimCOP(parent_v, &r->VV[0].StoreId, &r->sid);
+		    ReintPrelimCOP(child_v, &NullSid, &r->sid);
 
 		    {
 			int opcode = (parent_v->d_needsres)
 			  ? ResolveViceSymLink_OP : RES_SymLink_OP;
-			if ((errorCode = SpoolVMLogRecord(vlist, parent_v, 
-							 volptr, &r->sid,
-							 opcode, r->Name[0],
-							 r->Fid[1].Vnode,
-							 r->Fid[1].Unique))) {
-			    SLog(0, 
-				   "Reint: Error %d during spool log record for ViceSymLink\n",
-				   errorCode);
+			UserId owner = child_v->vptr->disk.owner;
+			errorCode = SpoolVMLogRecord(vlist, parent_v, volptr,
+						     &r->sid, opcode,
+						     r->Name[0],
+						     r->Fid[1].Vnode,
+						     r->Fid[1].Unique,
+						     owner);
+			if (errorCode) {
+			    SLog(0, "Reint: Error %d during spool log record for ViceSymLink\n", errorCode);
 			    goto Exit;
 			}
 		    }
@@ -2002,7 +2019,7 @@ START_TIMING(Reintegrate_CheckSemanticsAndPerform);
 	if (count < Yield_CheckAndPerform_Period - 1)
 	    PollAndYield();
     }
-    SLog(1, "Starting  BulkTransfers for %#x", Vid);
+    SLog(1, "Starting  BulkTransfers for %x", Vid);
 
     /* Make sure we don't get killed by accident */
     he = client->VenusId;
@@ -2120,7 +2137,7 @@ START_TIMING(Reintegrate_PutObjects);
     SLog(10, 	"PutReintegrateObjects: Vid = %x, errorCode = %d",
 	     volptr ? V_id(volptr) : 0, errorCode);
 
-    ViceStoreId sid;
+    ViceStoreId sid = { 0, };
     struct dllist_head *p;
     int count = 0;
 
@@ -2151,7 +2168,8 @@ START_TIMING(Reintegrate_PutObjects);
 	dlist_iterator next(*vlist);
 	vle *v;
 	while ((v = (vle *)next())) {
-	    if ((!ISDIR(v->fid) || v->d_reintupdate) && !v->vptr->delete_me) {
+	    if ((v->vptr->disk.type != vDirectory || v->d_reintupdate) &&
+		!v->vptr->delete_me) {
 		ReintFinalCOP(v, volptr, NewVS);
 	    } else {
 		SLog(2, "PutReintegrateObjects: un-mutated or deleted fid %s",
@@ -2159,13 +2177,15 @@ START_TIMING(Reintegrate_PutObjects);
 	    }
 
 	    /* write down stale directory fids */
-	    if (ISDIR(v->fid) && v->d_reintstale && StaleDirs) { /* compatibility check */
+	    if (StaleDirs && v->vptr->disk.type == vDirectory && 
+		(v->d_reintstale || v->d_needsres)) { /* compatibility check */
 		ViceFid fid = v->fid;
 		fid.Volume = V_groupId(volptr);
 		SLog(0, "PutReintegrateObjects: stale directory fid %s, num %d, max %d",
 		     FID_(&fid), *NumDirs, MaxDirs);
 		if (*NumDirs < MaxDirs) {
-		    StaleDirs[(*NumDirs)] = v->fid;	/* send back replicated ID */
+		    StaleDirs[(*NumDirs)] = v->fid;
+		    /* send back replicated ID */
 		    StaleDirs[(*NumDirs)++].Volume = V_groupId(volptr);
 		}
 	    }
@@ -2186,13 +2206,9 @@ START_TIMING(Reintegrate_PutObjects);
 	    int i = 0;
 
 	    /* replace the entry for this client if one exists */
-	    while (i < volptr->nReintegrators) {
-		if (volptr->reintegrators[i].Host == sid.Host) {
-		    volptr->reintegrators[i] = sid;
+	    for (i = 0; i < volptr->nReintegrators; i++)
+		if (volptr->reintegrators[i].Host == sid.Host)
 		    break;
-		}
-		i++;
-	    }
 
 	    /* no entry for this client, make one */
 	    if (i == volptr->nReintegrators) {
@@ -2202,14 +2218,14 @@ START_TIMING(Reintegrate_PutObjects);
 			malloc(sizeof(ViceStoreId) * (i + VNREINTEGRATORS));
 		    if (volptr->reintegrators) {
 			memcpy(newlist, volptr->reintegrators,
-			       sizeof(ViceStoreId) * (i + VNREINTEGRATORS));
+			       sizeof(ViceStoreId) * i);
 			free(volptr->reintegrators);
 		    }
 		    volptr->reintegrators = newlist;
 		}
-		volptr->reintegrators[i] = sid;
 		volptr->nReintegrators++;
 	    }
+	    volptr->reintegrators[i] = sid;
 	}
     }
 
@@ -2247,7 +2263,7 @@ static int AllocReintegrateVnode(Volume **volptr, dlist *vlist,
     vle *v; v = AddVLE(*vlist, cFid);
     CODA_ASSERT(v->vptr == 0);
     v->vptr = vptr;
-    if ( ISDIR(*cFid) )
+    if (v->vptr->disk.type == vDirectory)
 	    v->d_inodemod = 1;
 
 Exit:
@@ -2402,14 +2418,19 @@ static int ReintNormalVCmp(int ReplicatedOp, VnodeType type,
 
 /* This probably ought to be folded into the PerformXXX routines!  -JJK */
 static void ReintPrelimCOP(vle *v, const ViceStoreId *OldSid,
-			   ViceStoreId *NewSid, Volume *volptr) 
+			   const ViceStoreId *NewSid) 
 {
-	/* Directories which are not identical to "old" contents MUST be
-	   stamped with unique Sid at end! */
-	if (!SID_EQ(Vnode_vv(v->vptr).StoreId, *OldSid))
-	    v->d_needsres = 1;
-	
-	Vnode_vv(v->vptr).StoreId = *NewSid;
+    ViceStoreId *current = &Vnode_vv(v->vptr).StoreId;
+
+    /* Directories which are not identical to "old" contents MUST be
+       stamped with unique Sid at end! */
+    if (v->vptr->disk.type == vDirectory && !SID_EQ(*current, *OldSid)) {
+	SLog(10,  "ReintPrelimCOP: %s needsres (sid %x.%x != oldsid %x.%x)", FID_(&v->fid),
+	     current->Host, current->Uniquifier, OldSid->Host, OldSid->Uniquifier);
+	v->d_needsres = 1;
+    }
+
+    *current = *NewSid;
 }
 
 
@@ -2435,7 +2456,9 @@ static void ReintFinalCOP(vle *v, Volume *volptr, RPC2_Integer *VS)
 	   (2) we must log a ResolveNULL_OP so that resolution 
 	   works correctly. 
 	*/
-	if (v->vptr->disk.type == vDirectory && v->d_needsres) {
+	if (v->vptr->disk.type == vDirectory && v->d_needsres &&
+	    AllowResolution && V_RVMResOn(volptr))
+	{
 	    int ret = SpoolVMLogRecord(NULL, v, volptr, FinalSid,
 				       ResolveNULL_OP, 0);
 	    CODA_ASSERT(ret == 0);
