@@ -126,9 +126,11 @@ long FS_ViceDisconnectFS(RPC2_Handle RPCid)
 {
     ClientEntry *client = 0;
     long   errorCode;
+    char *rock;
 
     SLog(1, "ViceDisconnectFS");
-    errorCode = RPC2_GetPrivatePointer(RPCid, (char **)&client);
+    errorCode = RPC2_GetPrivatePointer(RPCid, &rock);
+    client = (ClientEntry *)rock;
 
     if (!errorCode && client) {
 	struct Lock *lock = &client->VenusId->lock;
@@ -154,8 +156,16 @@ long FS_ViceDisconnectFS(RPC2_Handle RPCid)
 */
 long FS_TokenExpired(RPC2_Handle RPCid)
 {
+    ClientEntry *client = 0;
+    long   errorCode;
+    char *rock;
+
     SLog(100, "TokenExpired");
-    FS_ViceDisconnectFS(RPCid);
+    errorCode = RPC2_GetPrivatePointer(RPCid, &rock);
+    client = (ClientEntry *)rock;
+
+    if (!errorCode && client)
+	CLIENT_CleanUpHost(client->VenusId);
 
     return(RPC2_NAKED);
 }
@@ -266,6 +276,7 @@ long FS_ViceGetVolumeStatus(RPC2_Handle RPCid, VolumeId vid, VolumeStatus *statu
     int		aCLSize;
     int		rights;
     int		anyrights;
+    char *rock;
 
     errorCode = fileCode = 0;
     vptr = 0;
@@ -313,8 +324,9 @@ long FS_ViceGetVolumeStatus(RPC2_Handle RPCid, VolumeId vid, VolumeStatus *statu
 
     SetAccessList(vptr, aCL, aCLSize);
 
-    if((errorCode = RPC2_GetPrivatePointer(RPCid, (char **)&client)) != RPC2_SUCCESS)
+    if((errorCode = RPC2_GetPrivatePointer(RPCid, &rock)) != RPC2_SUCCESS)
 	goto Final;
+    client = (ClientEntry *)rock;
 
     if(!client) {
 	errorCode = EFAULT;
@@ -535,12 +547,14 @@ long FS_ViceSetRootVolume(RPC2_Handle RPCid, RPC2_String volume)
     long errorCode = 0;
     ClientEntry * client;	/* pointer to client entry */
     int fd, rc, len;
+    char *rock;
 
     SLog(1,"ViceSetRootVolume to %s", (char *)volume);
 
-    errorCode = RPC2_GetPrivatePointer(RPCid, (char **)&client);
+    errorCode = RPC2_GetPrivatePointer(RPCid, &rock);
     if (errorCode != RPC2_SUCCESS)
 	goto exit;
+    client = (ClientEntry *)rock;
 
     if (!client) {
 	errorCode = EFAULT;
@@ -593,14 +607,16 @@ long FS_ViceGetTime(RPC2_Handle RPCid, RPC2_Unsigned *seconds,
 	struct timezone tspl;
 	ClientEntry *client = NULL;
 	long errorCode;
+	char *rock;
 
 	TM_GetTimeOfDay(&tpl,&tspl);
 	*seconds = tpl.tv_sec;
 	*useconds = tpl.tv_usec;
 
-	errorCode = RPC2_GetPrivatePointer(RPCid, (char **)&client);
+	errorCode = RPC2_GetPrivatePointer(RPCid, &rock);
+	client = (ClientEntry *)rock;
 
-	if (!client) { 
+	if (errorCode || !client) { 
 		SLog(0, "No client structure built by ViceNewConnection");
 		return ENOTCONN;
 	}
@@ -907,8 +923,8 @@ static void SetSystemStats_bsd44(ViceStatistics *stats)
  * running on the server host. */
 void SetSystemStats_linux(ViceStatistics *stats)
 {
-    unsigned long d1, d2, d3, d4;
-    static char   line[1024];
+    uint32_t d1, d2, d3, d4;
+    static char line[1024];
     FILE *f;
 
 #define PARSELINE(file, pattern, args...) do { int i; \
@@ -919,19 +935,19 @@ void SetSystemStats_linux(ViceStatistics *stats)
 
     f = fopen("/proc/stat", "r");
     if (f) {
-	PARSELINE(f, "cpu %lu %lu %lu %lu", &stats->UserCPU, &stats->NiceCPU,
+	PARSELINE(f, "cpu %u %u %u %u", &stats->UserCPU, &stats->NiceCPU,
 		  &stats->SystemCPU, &stats->IdleCPU);
-	PARSELINE(f, "disk %lu %lu %lu %lu", &d1, &d2, &d3, &d4);
+	PARSELINE(f, "disk %u %u %u %u", &d1, &d2, &d3, &d4);
 	stats->TotalIO = d1 + d2 + d3 + d4;
-        PARSELINE(f, "btime %lu", &stats->BootTime);
+        PARSELINE(f, "btime %u", &stats->BootTime);
 	fclose(f);
     }
 
     f = fopen("/proc/self/status", "r");
     if (f) {
-	PARSELINE(f, "VmSize: %lu kB", &stats->ProcessSize);
-	PARSELINE(f, "VmRSS: %lu kB",  &stats->VmRSS);
-	PARSELINE(f, "VmData: %lu kB", &stats->VmData);
+	PARSELINE(f, "VmSize: %u kB", &stats->ProcessSize);
+	PARSELINE(f, "VmRSS: %u kB",  &stats->VmRSS);
+	PARSELINE(f, "VmData: %u kB", &stats->VmData);
 	fclose(f);
     }
 }
@@ -983,12 +999,14 @@ long FS_ViceNewConnectFS(RPC2_Handle RPCid, RPC2_Unsigned ViceVersion,
 {
     long errorCode;
     ClientEntry *client = NULL;
+    char *rock;
 
     SLog(1, "FS_ViceNewConnectFS (version %d) for user %s at %s.%s",
          ViceVersion, ClientId->UserName, ClientId->WorkStationName, 
          ClientId->VenusName);
 
-    errorCode = RPC2_GetPrivatePointer(RPCid, (char **)&client);
+    errorCode = RPC2_GetPrivatePointer(RPCid, &rock);
+    client = (ClientEntry *)rock;
 
     if (errorCode || !client) {
         SLog(0, "No client structure built by ViceNewConnection");
