@@ -280,7 +280,7 @@ struct Volume {
     byte	specialStatus;	/* An error code to return on VGetVolume: the
 				   volume is unavailable for the reason quoted,
 				   currently VBUSY or VMOVED */
-    long	updateTime;	/* Time that this volume was put on the updated
+    int32_t	updateTime;	/* Time that this volume was put on the updated
 				   volume list--the list of volumes that will be
 				   salvaged should the file server crash */
     struct	Lock lock;	/* internal lock */
@@ -443,9 +443,8 @@ extern void InitLRU(int howmany);
 /* partition disk usage related routines */
 
 /* exported routines */
-void VAdjustDiskUsage(Error *ec, Volume *vp, int blocks);
-void VCheckDiskUsage(Error *ec, Volume *vp, int blocks);
-void VGetPartitionStatus(Volume *vp, int *totalBlocks, int *freeBlocks);
+Error VAdjustDiskUsage(Volume *vp, int blocks);
+Error VCheckDiskUsage(Volume *vp, int blocks);
 void PutVolObj(Volume **volptr, int LockLevel, int Dequeue);
 int GetVolObj(VolumeId Vid, Volume **volptr, 
 	      int LockLevel, int Enque, int LockerAddress);
