@@ -471,20 +471,20 @@ int dumpstream::getVnodeIndex(VnodeClass Type, long *nVnodes, long *listsize)
 int dumpstream::skip_vnode_garbage()
 {
     char buf[4096];
-    int size; 
+    unsigned int size; 
     
     int tag = fgetc(stream);
 
     if (tag == D_DIRPAGES) {
-	long npages;
+	unsigned int npages;
 	int size = DIR_PAGESIZE;
 
 	CODA_ASSERT (IndexType == vLarge);
 	LogMsg(10, VolDebugLevel, stdout, "SkipVnodeData: Skipping dirpages for %s", name);
-	if (!GetInt32(stream, (unsigned int *)&npages))
+	if (!GetInt32(stream, &npages))
 	    return -1;
 	
-	for (int i = 0; i < npages; i++){ 	/* Skip directory pages */
+	for (unsigned int i = 0; i < npages; i++){ 	/* Skip directory pages */
 	    tag = fgetc(stream);
 	    if (tag != 'P'){
 		LogMsg(0, VolDebugLevel, stderr, "Restore: Dir page does not have a P tag");
@@ -494,12 +494,12 @@ int dumpstream::skip_vnode_garbage()
 	} 
     } else if (tag == D_FILEDATA) {
 	size = (int) sizeof(buf);
-	long nbytes, filesize;
+	unsigned int nbytes, filesize;
 
 	CODA_ASSERT (IndexType == vSmall);
 	LogMsg(10, VolDebugLevel, stdout, "SkipVnodeData: Skipping file data for %s", name);
 
-	if (!GetInt32(stream, (unsigned int *)&filesize))
+	if (!GetInt32(stream, &filesize))
 	    return -1;
 
 	for (nbytes = filesize; nbytes; nbytes -= size) { /* Skip the filedata */
@@ -690,27 +690,27 @@ int dumpstream::getNextVnode(VnodeDiskObject *vdop, VnodeId *vnodeNumber, int *d
 
 /* Copy the file or directory data which should be next in the stream to out */
 /* Actually use the bogus Dump mechanism in DumpFD, it should be rewritten soon.*/
-extern byte *Reserve(DumpBuffer_t *, int);
+extern char *Reserve(DumpBuffer_t *, int);
 int
 dumpstream::copyVnodeData(DumpBuffer_t *dbuf)
 {
     int tag = fgetc(stream);
     char buf[DIR_PAGESIZE];
-    int nbytes;
+    unsigned int nbytes;
 
     LogMsg(10, VolDebugLevel, stdout, "Copy:%s type %x", (IndexType == vLarge?"Large":"Small"), tag);
     if (IndexType == vLarge) {
 	CODA_ASSERT(tag == D_DIRPAGES); /* Do something similar for dirpages. */
 
 	/* We get a number of pages, pages are DIR_PAGESIZE bytes long. */
-	long num_pages;
+	unsigned int num_pages;
 	
-	if (!GetInt32(stream, (unsigned int *)&num_pages))
+	if (!GetInt32(stream, &num_pages))
 	    return -1;
 
 	DumpInt32(dbuf, D_DIRPAGES, num_pages);
 
-	for (int i = 0; i < num_pages; i++) { /* copy DIR_PAGESIZE bytes to output. */
+	for (unsigned int i = 0; i < num_pages; i++) { /* copy DIR_PAGESIZE bytes to output. */
 	    tag = fgetc(stream);
 	    if (tag != 'P'){
 		LogMsg(0, VolDebugLevel, stderr, "Restore: Dir page does not have a P tag");
@@ -721,23 +721,23 @@ dumpstream::copyVnodeData(DumpBuffer_t *dbuf)
 		LogMsg(0, VolDebugLevel, stderr, "Error reading dump file %s.", name);
 		return -1;
 	    }
-	    DumpByteString(dbuf, (byte)'P', (byte *)buf, DIR_PAGESIZE);
+	    DumpByteString(dbuf, 'P', buf, DIR_PAGESIZE);
 	}
     } else if (IndexType == vSmall) {
 	/* May not have a file associated with this vnode? don't think so...*/
 	CODA_ASSERT(tag == D_FILEDATA);
 
 	/* First need to output the tag and the length */
-	long filesize, size = DIR_PAGESIZE;
+	unsigned int filesize, size = DIR_PAGESIZE;
 	if (!GetInt32(stream, (unsigned int *)&filesize)) 
 	    return -1;
-	byte *p;
+	char *p;
 	DumpInt32(dbuf, D_FILEDATA, filesize);
 	for (nbytes = filesize; nbytes; nbytes -= size) {
 	    if (nbytes < size)
 		size = nbytes;
 	    p = Reserve(dbuf, size);	/* Mark off size bytes in output */
-	    if (fread((char *)p, size, 1, stream) != 1) {
+	    if (fread(p, size, 1, stream) != 1) {
 		LogMsg(0, VolDebugLevel, stderr, "Error reading dump file %s.", name);
 		return -1;
 	    }
@@ -846,11 +846,15 @@ int dumpstream::CopyBytesToFile(FILE *outfile, int nbytes) {
 }
 
 
-void PrintDumpHeader(FILE * outfile, struct DumpHeader *dh) {
-    fprintf(outfile, "Volume id = 0x%08lx, Volume name = '%s'\n", 
+void PrintDumpHeader(FILE * outfile, struct DumpHeader *dh)
+{
+    time_t timestamp;
+
+    fprintf(outfile, "Volume id = %08x, Volume name = '%s'\n", 
 	 dh->volumeId, dh->volumeName);
-    fprintf(outfile, "Parent id = 0x%08lx  Timestamp = %s", 
-	 dh->parentId, ctime((time_t *)&dh->backupDate));
-    fprintf(outfile, "Dump uniquifiers: oldest = 0x%08x   latest = 0x%08x\n",
+    timestamp = (time_t)dh->backupDate;
+    fprintf(outfile, "Parent id = %08x  Timestamp = %s", 
+	 dh->parentId, ctime(&timestamp));
+    fprintf(outfile, "Dump uniquifiers: oldest = %08x   latest = %08x\n",
 	 dh->oldest, dh->latest);
 }
