@@ -19,10 +19,6 @@ listed in the file CREDITS.
 #include <config.h>
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include <unistd.h>
 #include <errno.h>
 
@@ -33,10 +29,6 @@ extern "C" {
 #include <sys/file.h>
 #endif
 
-#ifdef __cplusplus
-}
-#endif
-
 int myflock(int fd, int type, int block) {
 #ifdef HAVE_FCNTL_LOCKING
     struct flock lock;
